==> paraview-v5.2.0-RC1.zip: paraview-v5.2.0-RC1/Applications/ParaView/ParaViewMainWindow.h <==
/*=========================================================================

   Program: ParaView
   Module:    ParaViewMainWindow.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef ParaViewMainWindow_h
#define ParaViewMainWindow_h

#include <QMainWindow>

/// MainWindow for the default ParaView application.
class ParaViewMainWindow : public QMainWindow
{
  Q_OBJECT
  typedef QMainWindow Superclass;
public:
  ParaViewMainWindow();
  ~ParaViewMainWindow();

protected:
  void dragEnterEvent(QDragEnterEvent *evt);
  void dropEvent(QDropEvent *evt);
  void showEvent(QShowEvent * evt);

protected slots:
  void showHelpForProxy(const QString& proxyname, const QString& groupname);
  void showWelcomeDialog();

private:
  Q_DISABLE_COPY(ParaViewMainWindow)

  class pqInternals;
  pqInternals* Internals;
};

#endif

==> paraview-v5.3.0-RC1.zip: paraview-v5.3.0-RC1/Applications/ParaView/ParaViewMainWindow.h <==
/*=========================================================================

   Program: ParaView
   Module:    ParaViewMainWindow.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef ParaViewMainWindow_h
#define ParaViewMainWindow_h

#include <QMainWindow>

/// MainWindow for the default ParaView application.
class ParaViewMainWindow : public QMainWindow
{
  Q_OBJECT
  typedef QMainWindow Superclass;

public:
  ParaViewMainWindow();
  ~ParaViewMainWindow();

protected:
  void dragEnterEvent(QDragEnterEvent* evt);
  void dropEvent(QDropEvent* evt);
  void showEvent(QShowEvent* evt);

protected slots:
  void showHelpForProxy(const QString& groupname, const QString& proxyname);
  void showWelcomeDialog();

private:
  Q_DISABLE_COPY(ParaViewMainWindow)

  class pqInternals;
  pqInternals* Internals;
};

#endif
